@@ -14,4 +14,6 @@ class resolution:
         monitors = [m for m in get_monitors()]
         resolution.resolutions = [(m.width, m.height) for m in monitors]
         resolution.index = [m.is_primary for m in monitors].index(True)
-        resolution.resolution = resolution.resolutions[resolution.index]
\ No newline at end of file
+        resolution.resolution = resolution.resolutions[resolution.index]
+    def percentile(x, y):
+        return [self.resolution[0]/100*x, self.resolution[1]/100*y]
\ No newline at end of file
